import { SyntheticEvent } from "react";
interface InputProps extends React.InputHTMLAttributes<HTMLInputElement> {
}
interface RootProps extends React.HTMLAttributes<HTMLElement> {
}
interface UploaderHookAPI {
    getInputProps: () => InputProps;
    getRootProps: () => RootProps;
    acceptedFilesData: AcceptedFilesData;
    rejectedFilesData: RejectedFilesData;
    deleteFile: (fileIndex: number) => void;
    deleteAllFiles: () => void;
}
declare type AcceptedFilesData = Array<{
    file: File;
    preview: string;
}>;
declare type RejectedFilesData = Array<{
    file: File;
    errors: string[];
}>;
export interface UploaderHookParams {
    multiple?: boolean;
    accept?: string;
    maxSize?: number;
    onAttach?: (acceptedFilesData: AcceptedFilesData, refectedFilesData: RejectedFilesData, event: SyntheticEvent) => void;
}
declare type UploaderHook = (params: UploaderHookParams) => UploaderHookAPI;
/**
 * Provides access:
 *
 * - to attached files by DnD or with help of input[type="file"];
 * - to validation errors;
 * - to the api to manage the attached file.
 *
 * @param {Object} [config] Configuration options object.
 * @param {number} [config.maxSize] Maximum bytes of data allowed to upload.
 * @param {string} [config.accept] Files types allowed to upload.
 * @param {boolean} [config.multiple=false] To allow or not multiple files upload.
 * @param {onAttach} [config.onAttach=() => {}] To allow or not multiple files upload.
 *
 * @returns {Object} api Api to manage attached files.
 */
export declare const useUploaderHook: UploaderHook;
export {};
